summaryrefslogtreecommitdiffstats
path: root/shared
diff options
context:
space:
mode:
authorJohn Ahlroos <john@vaadin.com>2012-09-07 10:09:02 +0300
committerJohn Ahlroos <john@vaadin.com>2012-09-07 10:23:35 +0300
commit074b1095ee302af67626055820853ed1b8a4ea86 (patch)
treea6a6c72465748cb97fc83f5a84f37e151b7618de /shared
parent4222b99bf020c8d7a3d49f4105507be4308cddd2 (diff)
downloadvaadin-framework-074b1095ee302af67626055820853ed1b8a4ea86.tar.gz
vaadin-framework-074b1095ee302af67626055820853ed1b8a4ea86.zip
Now using HTML5 content mode. Also deprecated the XHTML content modes.
Diffstat (limited to 'shared')
-rw-r--r--shared/src/com/vaadin/shared/ui/label/ContentMode.java12
1 files changed, 10 insertions, 2 deletions
diff --git a/shared/src/com/vaadin/shared/ui/label/ContentMode.java b/shared/src/com/vaadin/shared/ui/label/ContentMode.java
index 1927b6c01b..3e6e5b8e45 100644
--- a/shared/src/com/vaadin/shared/ui/label/ContentMode.java
+++ b/shared/src/com/vaadin/shared/ui/label/ContentMode.java
@@ -15,6 +15,7 @@
*/
package com.vaadin.shared.ui.label;
+
/**
* Content modes defining how the client should interpret a Label's value.
*
@@ -33,9 +34,16 @@ public enum ContentMode {
PREFORMATTED,
/**
- * Content mode, where the label contains XHTML. Care should be taken to
- * ensure
+ * Content mode, where the label contains HTML.
+ */
+ HTML,
+
+ /**
+ * Content mode, where the label contains XHTML.
+ *
+ * @deprecated Use {@link ContentMode.HTML}
*/
+ @Deprecated
XHTML,
/**